import { Component, OnDestroy } from '@angular/core';
import { Router, ActivatedRoute, NavigationEnd } from '@angular/router';
import { Subscription } from 'rxjs/Subscription';
import { Sensor } from '@overflow/commons-typescript/model/sensor';
import { BreadcrumbService } from '@app/commons/service/breadcrumb.service';

@Component({
  selector: 'of-pages-sensor',
  templateUrl: './sensor-page.component.html',
})
export class SensorPageComponent {

  isDetail: boolean;
  sensorID: string;

  constructor(
    private router: Router,
    private route: ActivatedRoute,
    private breadcrumbService: BreadcrumbService
  ) {
    this.route.params.subscribe(params => {
      if (params['id']) {
        this.onDetailContainer(params['id']);
      } else {
        this.onListContainer();
      }
    });
  }

  onListContainer() {
    this.breadcrumbService.setItems([
      { label: 'Sensor', routerLink: ['/sensor/list'],  }
    ]);
    this.isDetail = false;
  }

  onDetailContainer(sensorHostID: string) {
    this.sensorID = sensorHostID;
    this.breadcrumbService.setItems([
      { label: 'Sensor', routerLink: ['/sensor/list'] },
      { label: this.sensorID }
    ]);
    this.isDetail = true;
  }

  onSensorSelect(sensor: Sensor) {
    this.router.navigate(['sensor', sensor.id, 'info']);
  }

}
